@@ -30,7 +30,7 @@ class ListHistory(BaseLister):
         parser = super(ListHistory, self).get_parser(parser)
 
         parser.add_argument('--validation',
-                            metavar="<validation>",
+                            metavar="<validation_id>",
                             type=str,
                             help='Display execution history for a validation')
         parser.add_argument('--limit',
@@ -62,15 +62,16 @@ class ListHistory(BaseLister):
                 "{} last validations.").format(
                 parsed_args.history_limit))
 
-        actions = ValidationActions(parsed_args.validation_log_dir)
+        actions = ValidationActions()
 
         return actions.show_history(
             validation_ids=parsed_args.validation,
+            log_path=parsed_args.validation_log_dir,
             history_limit=parsed_args.history_limit)
 
 
 class GetHistory(BaseCommand):
-    """Display details about a Validation execution"""
+    """Display details about a specific Validation execution"""
 
     def get_parser(self, parser):
         parser = super(GetHistory, self).get_parser(parser)
