@@ -22,20 +22,32 @@ from validations_libs.cli.parseractions import CommaListAction
 
 
 class ValidationList(Lister):
-    """Validation List client implementation class"""
+    """List the Validations Catalog"""
 
     def get_parser(self, parser):
         """Argument parser for validation run"""
         parser = super(ValidationList, self).get_parser(parser)
         parser.add_argument('--group', '-g',
-                            metavar='<group>[,<group>,...]',
+                            metavar='<group_id>[,<group_id>,...]',
                             action=CommaListAction,
                             default=[],
                             help=("List specific group of validations, "
                                   "if more than one group is required "
-                                  "separate the group names with commas: "
-                                  "--group pre-upgrade,prep | "
-                                  "--group openshift-on-openstack"))
+                                  "separate the group names with commas."))
+        parser.add_argument('--category',
+                            metavar='<category_id>[,<category_id>,...]',
+                            action=CommaListAction,
+                            default=[],
+                            help=("List specific category of validations, "
+                                  "if more than one category is required "
+                                  "separate the category names with commas."))
+        parser.add_argument('--product',
+                            metavar='<product_id>[,<product_id>,...]',
+                            action=CommaListAction,
+                            default=[],
+                            help=("List specific product of validations, "
+                                  "if more than one product is required "
+                                  "separate the product names with commas."))
         parser.add_argument('--validation-dir', dest='validation_dir',
                             default=constants.ANSIBLE_VALIDATION_DIR,
                             help=("Path where the validation playbooks "
@@ -46,7 +58,11 @@ class ValidationList(Lister):
         """Take validation action"""
 
         group = parsed_args.group
+        category = parsed_args.category
+        product = parsed_args.product
         validation_dir = parsed_args.validation_dir
 
         v_actions = ValidationActions(validation_path=validation_dir)
-        return (v_actions.list_validations(group))
+        return (v_actions.list_validations(groups=group,
+                                           categories=category,
+                                           products=product))
