@@ -15,6 +15,7 @@
 #   under the License.
 
 from cliff.show import ShowOne
+from cliff.lister import Lister
 
 from validations_libs.validation_actions import ValidationActions
 from validations_libs import constants
@@ -22,7 +23,7 @@ from validations_libs.cli.parseractions import CommaListAction
 
 
 class Show(ShowOne):
-    """Validation Show client implementation class"""
+    """Show detailed informations about a Validation"""
 
     def get_parser(self, parser):
         """Argument parser for validation show"""
@@ -50,34 +51,34 @@ class Show(ShowOne):
             return data.keys(), data.values()
 
 
-class ShowGroup(ShowOne):
-    """Validation Show group client implementation class"""
+class ShowGroup(Lister):
+    """Show detailed informations about Validation Groups"""
 
     def get_parser(self, parser):
         """Argument parser for validation show group"""
         parser = super(ShowGroup, self).get_parser(parser)
+
         parser.add_argument('--validation-dir', dest='validation_dir',
                             default=constants.ANSIBLE_VALIDATION_DIR,
                             help=("Path where the validation playbooks "
                                   "are located."))
-        parser.add_argument('--group', '-g',
-                            metavar='<group_name>',
-                            dest="group",
-                            help=("Show a specific group."))
+
         return parser
 
     def take_action(self, parsed_args):
         """Take validation action"""
-        # Get parameters:
-        validation_dir = parsed_args.validation_dir
-        group = parsed_args.group
 
-        v_actions = ValidationActions(validation_path=validation_dir)
-        return v_actions.group_information(group)
+        v_actions = ValidationActions(parsed_args.validation_dir)
+        return v_actions.group_information(constants.VALIDATION_GROUPS_INFO)
 
 
 class ShowParameter(ShowOne):
-    """Display Validations Parameters"""
+    """Show Validation(s) parameter(s)
+
+    Display Validation(s) Parameter(s) which could be overriden during an
+    execution. It could be filtered by **validation_id**, **group(s)**,
+    **category(ies)** or by **products**.
+    """
 
     def get_parser(self, parser):
         parser = super(ShowParameter, self).get_parser(parser)
@@ -96,9 +97,7 @@ class ShowParameter(ShowOne):
             default=[],
             help=("List specific validations, "
                   "if more than one validation is required "
-                  "separate the names with commas: "
-                  "--validation check-ftype,512e | "
-                  "--validation 512e")
+                  "separate the names with commas.")
         )
 
         ex_group.add_argument(
@@ -108,11 +107,27 @@ class ShowParameter(ShowOne):
             default=[],
             help=("List specific group validations, "
                   "if more than one group is required "
-                  "separate the group names with commas: "
-                  "pre-upgrade,prep | "
-                  "openshift-on-openstack")
+                  "separate the group names with commas.")
         )
 
+        ex_group.add_argument(
+            '--category',
+            metavar='<category_id>[,<category_id>,...]',
+            action=CommaListAction,
+            default=[],
+            help=("List specific validations by category, "
+                  "if more than one category is required "
+                  "separate the category names with commas."))
+
+        ex_group.add_argument(
+            '--product',
+            metavar='<product_id>[,<product_id>,...]',
+            action=CommaListAction,
+            default=[],
+            help=("List specific validations by product, "
+                  "if more than one product is required "
+                  "separate the product names with commas."))
+
         parser.add_argument(
             '--download',
             action='store',
@@ -138,10 +153,12 @@ class ShowParameter(ShowOne):
     def take_action(self, parsed_args):
         v_actions = ValidationActions(parsed_args.validation_dir)
         params = v_actions.show_validations_parameters(
-            parsed_args.validation_name,
-            parsed_args.group,
-            parsed_args.format_output,
-            parsed_args.download)
+            validations=parsed_args.validation_name,
+            groups=parsed_args.group,
+            categories=parsed_args.category,
+            products=parsed_args.product,
+            output_format=parsed_args.format_output,
+            download_file=parsed_args.download)
 
         if parsed_args.download:
             self.app.LOG.info(
