@@ -12,17 +12,28 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 #
+"""Default paths for validation playbook directory,
+validation groups definitions and validation logs
+are defined here.
+
+These paths are used in an absence of user defined overrides,
+or as a fallback, when custom locations fail.
+"""
+
 import os
 
 DEFAULT_VALIDATIONS_BASEDIR = '/usr/share/ansible'
 
-ANSIBLE_VALIDATION_DIR = '/usr/share/ansible/validation-playbooks'
+ANSIBLE_VALIDATION_DIR = os.path.join(
+    DEFAULT_VALIDATIONS_BASEDIR,
+    'validation-playbooks')
 
 VALIDATION_GROUPS_INFO = os.path.join(
     DEFAULT_VALIDATIONS_BASEDIR,
     'groups.yaml')
 
-VALIDATIONS_LOG_BASEDIR = os.path.join(os.environ.get('HOME'), 'validations')
+# NOTE(fressi) The HOME folder environment variable may be undefined.
+VALIDATIONS_LOG_BASEDIR = os.path.expanduser('~/validations')
 
 VALIDATION_ANSIBLE_ARTIFACT_PATH = os.path.join(
     VALIDATIONS_LOG_BASEDIR,
