@@ -13,10 +13,6 @@
 #   under the License.
 #
 
-try:
-    from unittest import mock
-except ImportError:
-    import mock
 from unittest import TestCase
 
 from validations_libs.cli import app
