@@ -13,12 +13,11 @@
 #   under the License.
 #
 import sys
-
+import copy
 try:
     from unittest import mock
 except ImportError:
     import mock
-from unittest import TestCase
 
 from validations_libs.cli import run
 from validations_libs.tests import fakes
@@ -43,7 +42,7 @@ class TestRun(BaseCommand):
 
     @mock.patch('validations_libs.validation_actions.ValidationActions.'
                 'run_validations',
-                return_value=fakes.FAKE_SUCCESS_RUN)
+                return_value=copy.deepcopy(fakes.FAKE_SUCCESS_RUN))
     def test_run_command_success(self, mock_run):
         arglist = ['--validation', 'foo']
         verifylist = [('validation_name', ['foo'])]
@@ -64,13 +63,15 @@ class TestRun(BaseCommand):
                 return_value='doe')
     @mock.patch('validations_libs.validation_actions.ValidationActions.'
                 'run_validations',
-                return_value=fakes.FAKE_SUCCESS_RUN)
+                return_value=copy.deepcopy(fakes.FAKE_SUCCESS_RUN))
     def test_run_command_extra_vars(self, mock_run, mock_user, mock_print,
                                     mock_log_dir):
         run_called_args = {
             'inventory': 'localhost',
             'limit_hosts': None,
             'group': [],
+            'category': [],
+            'product': [],
             'extra_vars': {'key': 'value'},
             'validations_dir': '/usr/share/ansible/validation-playbooks',
             'base_dir': '/usr/share/ansible',
@@ -96,13 +97,15 @@ class TestRun(BaseCommand):
                 return_value='doe')
     @mock.patch('validations_libs.validation_actions.ValidationActions.'
                 'run_validations',
-                return_value=fakes.FAKE_SUCCESS_RUN)
+                return_value=copy.deepcopy(fakes.FAKE_SUCCESS_RUN))
     def test_run_command_extra_vars_twice(self, mock_run, mock_user,
                                           mock_print, mock_log_dir):
         run_called_args = {
             'inventory': 'localhost',
             'limit_hosts': None,
             'group': [],
+            'category': [],
+            'product': [],
             'extra_vars': {'key': 'value2'},
             'validations_dir': '/usr/share/ansible/validation-playbooks',
             'base_dir': '/usr/share/ansible',
@@ -140,7 +143,7 @@ class TestRun(BaseCommand):
                 return_value='doe')
     @mock.patch('validations_libs.validation_actions.ValidationActions.'
                 'run_validations',
-                return_value=fakes.FAKE_SUCCESS_RUN)
+                return_value=copy.deepcopy(fakes.FAKE_SUCCESS_RUN))
     def test_run_command_extra_vars_file(self, mock_run, mock_user, mock_open,
                                          mock_yaml, mock_log_dir):
 
@@ -148,6 +151,8 @@ class TestRun(BaseCommand):
             'inventory': 'localhost',
             'limit_hosts': None,
             'group': [],
+            'category': [],
+            'product': [],
             'extra_vars': {'key': 'value'},
             'validations_dir': '/usr/share/ansible/validation-playbooks',
             'base_dir': '/usr/share/ansible',
@@ -172,12 +177,14 @@ class TestRun(BaseCommand):
                 return_value='doe')
     @mock.patch('validations_libs.validation_actions.ValidationActions.'
                 'run_validations',
-                return_value=fakes.FAKE_SUCCESS_RUN)
+                return_value=copy.deepcopy(fakes.FAKE_SUCCESS_RUN))
     def test_run_command_extra_env_vars(self, mock_run, mock_user, mock_log_dir):
         run_called_args = {
             'inventory': 'localhost',
             'limit_hosts': None,
             'group': [],
+            'category': [],
+            'product': [],
             'extra_vars': None,
             'validations_dir': '/usr/share/ansible/validation-playbooks',
             'base_dir': '/usr/share/ansible',
@@ -202,7 +209,7 @@ class TestRun(BaseCommand):
                 return_value='doe')
     @mock.patch('validations_libs.validation_actions.ValidationActions.'
                 'run_validations',
-                return_value=fakes.FAKE_SUCCESS_RUN)
+                return_value=copy.deepcopy(fakes.FAKE_SUCCESS_RUN))
     def test_run_command_extra_env_vars_with_custom_callback(self,
                                                              mock_run,
                                                              mock_user,
@@ -213,6 +220,8 @@ class TestRun(BaseCommand):
             'log_path': mock_log_dir,
             'quiet': False,
             'group': [],
+            'category': [],
+            'product': [],
             'extra_vars': None,
             'validations_dir': '/usr/share/ansible/validation-playbooks',
             'base_dir': '/usr/share/ansible',
@@ -236,12 +245,14 @@ class TestRun(BaseCommand):
                 return_value='doe')
     @mock.patch('validations_libs.validation_actions.ValidationActions.'
                 'run_validations',
-                return_value=fakes.FAKE_SUCCESS_RUN)
+                return_value=copy.deepcopy(fakes.FAKE_SUCCESS_RUN))
     def test_run_command_extra_env_vars_twice(self, mock_run, mock_user, mock_log_dir):
         run_called_args = {
             'inventory': 'localhost',
             'limit_hosts': None,
             'group': [],
+            'category': [],
+            'product': [],
             'extra_vars': None,
             'validations_dir': '/usr/share/ansible/validation-playbooks',
             'base_dir': '/usr/share/ansible',
@@ -267,7 +278,7 @@ class TestRun(BaseCommand):
                 return_value='doe')
     @mock.patch('validations_libs.validation_actions.ValidationActions.'
                 'run_validations',
-                return_value=fakes.FAKE_SUCCESS_RUN)
+                return_value=copy.deepcopy(fakes.FAKE_SUCCESS_RUN))
     def test_run_command_extra_env_vars_and_extra_vars(self,
                                                        mock_run,
                                                        mock_user,
@@ -276,6 +287,8 @@ class TestRun(BaseCommand):
             'inventory': 'localhost',
             'limit_hosts': None,
             'group': [],
+            'category': [],
+            'product': [],
             'extra_vars': {'key': 'value'},
             'validations_dir': '/usr/share/ansible/validation-playbooks',
             'base_dir': '/usr/share/ansible',
@@ -306,29 +319,34 @@ class TestRun(BaseCommand):
         self.assertRaises(Exception, self.check_parser, self.cmd,
                           arglist, verifylist)
 
+    @mock.patch('validations_libs.constants.VALIDATIONS_LOG_BASEDIR')
     @mock.patch('getpass.getuser',
                 return_value='doe')
     @mock.patch('validations_libs.validation_actions.ValidationActions.'
                 'run_validations',
-                return_value=fakes.FAKE_FAILED_RUN)
-    def test_run_command_failed_validation(self, mock_run, mock_user):
+                return_value=copy.deepcopy(fakes.FAKE_FAILED_RUN))
+    def test_run_command_failed_validation(self, mock_run, mock_user, mock_log_dir):
         run_called_args = {
             'inventory': 'localhost',
             'limit_hosts': None,
             'group': [],
-            'extra_vars': {'key': 'value'},
+            'category': [],
+            'product': [],
+            'extra_vars': None,
             'validations_dir': '/usr/share/ansible/validation-playbooks',
             'base_dir': '/usr/share/ansible',
             'validation_name': ['foo'],
-            'extra_env_vars': {'key2': 'value2'},
+            'extra_env_vars': None,
             'python_interpreter': sys.executable,
             'quiet': True,
-            'ssh_user': 'doe'}
+            'ssh_user': 'doe',
+            'log_path': mock_log_dir}
 
         arglist = ['--validation', 'foo']
         verifylist = [('validation_name', ['foo'])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.assertRaises(RuntimeError, self.cmd.take_action, parsed_args)
+        mock_run.assert_called_with(**run_called_args)
 
     @mock.patch('getpass.getuser',
                 return_value='doe')
@@ -340,6 +358,8 @@ class TestRun(BaseCommand):
             'inventory': 'localhost',
             'limit_hosts': None,
             'group': [],
+            'category': [],
+            'product': [],
             'extra_vars': {'key': 'value'},
             'validations_dir': '/usr/share/ansible/validation-playbooks',
             'base_dir': '/usr/share/ansible',
