@@ -16,7 +16,6 @@ try:
     from unittest import mock
 except ImportError:
     import mock
-from unittest import TestCase
 
 from validations_libs.cli import show
 from validations_libs.tests import fakes
@@ -48,21 +47,20 @@ class TestShowGroup(BaseCommand):
     @mock.patch('yaml.safe_load', return_value=fakes.GROUP)
     @mock.patch('six.moves.builtins.open')
     def test_show_validations_group_info(self, mock_open, mock_yaml, mock_actions):
-        arglist = ['--group', 'group.yaml']
-        verifylist = [('group', 'group.yaml')]
+        arglist = []
 
         mock_info = mock.MagicMock()
         mock_info.group_information = mock.MagicMock(return_value='foo')
         mock_actions.return_value = mock_info
 
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        parsed_args = self.check_parser(self.cmd, arglist, [])
 
         group_info = self.cmd.take_action(parsed_args)
 
         mock_actions.assert_called_once_with(
             validation_path=fakes.FAKE_VALIDATIONS_PATH)
 
-        mock_info.group_information.assert_called_once_with('group.yaml')
+        mock_info.group_information.assert_called_once()
 
         self.assertEqual('foo', group_info)
 
@@ -91,3 +89,19 @@ class TestShowParameter(BaseCommand):
         arglist = ['--group', 'prep']
         verifylist = [('group', ['prep'])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+    @mock.patch('validations_libs.validation_actions.ValidationActions.'
+                'show_validations_parameters')
+    def test_show_validations_parameters_by_categories(self, mock_show):
+        arglist = ['--category', 'os']
+        verifylist = [('category', ['os'])]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+
+    @mock.patch('validations_libs.validation_actions.ValidationActions.'
+                'show_validations_parameters')
+    def test_show_validations_parameters_by_products(self, mock_show):
+        arglist = ['--product', 'product1']
+        verifylist = [('product', ['product1'])]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
