@@ -128,14 +128,25 @@ def create_artifacts_dir(log_path=constants.VALIDATIONS_LOG_BASEDIR,
         raise RuntimeError()
 
 
-def parse_all_validations_on_disk(path, groups=None):
-    """Return a list of validations metadata which can be sorted by Groups
+def parse_all_validations_on_disk(path,
+                                  groups=None,
+                                  categories=None,
+                                  products=None):
+    """Return a list of validations metadata which can be sorted by Groups, by
+    Categories or by Products.
 
     :param path: The absolute path of the validations directory
     :type path: `string`
-    :param groups: Groups of validations. Could be a `list` or a
-                   comma-separated `string` of groups
-    :type groups: `list` or `string`
+
+    :param groups: Groups of validations
+    :type groups: `list`
+
+    :param categories: Categories of validations
+    :type categories: `list`
+
+    :param products: Products of validations
+    :type products: `list`
+
     :return: A list of validations metadata.
     :rtype: `list`
 
@@ -143,49 +154,86 @@ def parse_all_validations_on_disk(path, groups=None):
 
     >>> path = '/foo/bar'
     >>> parse_all_validations_on_disk(path)
-    [{'description': 'Detect whether the node disks use Advanced Format.',
+    [{'categories': ['storage'],
+      'products': ['product1'],
+      'description': 'Detect whether the node disks use Advanced Format.',
       'groups': ['prep', 'pre-deployment'],
       'id': '512e',
       'name': 'Advanced Format 512e Support'},
-     {'description': 'Make sure that the server has enough CPU cores.',
+     {'categories': ['system'],
+      'products': ['product1'],
+      'description': 'Make sure that the server has enough CPU cores.',
       'groups': ['prep', 'pre-introspection'],
       'id': 'check-cpu',
       'name': 'Verify if the server fits the CPU core requirements'}]
     """
+    if not isinstance(path, six.string_types):
+        raise TypeError("The 'path' argument must be a String")
 
-    results = []
     if not groups:
         groups = []
-    else:
-        groups = convert_data(groups)
+    elif not isinstance(groups, list):
+        raise TypeError("The 'groups' argument must be a List")
 
+    if not categories:
+        categories = []
+    elif not isinstance(categories, list):
+        raise TypeError("The 'categories' argument must be a List")
+
+    if not products:
+        products = []
+    elif not isinstance(products, list):
+        raise TypeError("The 'products' argument must be a List")
+
+    results = []
     validations_abspath = glob.glob("{path}/*.yaml".format(path=path))
 
     LOG.debug(
-        "Attempting to parse validations of groups `{}` from {}".format(
-            ','.join(groups),
-            validations_abspath
-        )
+        "Attempting to parse validations by:\n"
+        "  - groups: {}\n"
+        "  - categories: {}\n"
+        "  - products: {}\n"
+        "from {}".format(groups, categories, products, validations_abspath)
     )
 
     for playbook in validations_abspath:
         val = Validation(playbook)
 
-        if not groups or set(groups).intersection(val.groups):
+        if not groups and not categories and not products:
             results.append(val.get_metadata)
+            continue
+
+        if set(groups).intersection(val.groups) or \
+           set(categories).intersection(val.categories) or \
+           set(products).intersection(val.products):
+            results.append(val.get_metadata)
+
     return results
 
 
-def get_validations_playbook(path, validation_id=None, groups=None):
-    """Get a list of validations playbooks paths either by their names
-    or their groups
+def get_validations_playbook(path,
+                             validation_id=None,
+                             groups=None,
+                             categories=None,
+                             products=None):
+    """Get a list of validations playbooks paths either by their names,
+    their groups, by their categories or by their products.
 
     :param path: Path of the validations playbooks
     :type path: `string`
+
     :param validation_id: List of validation name
-    :type validation_id: `list` or a `string` of comma-separated validations
+    :type validation_id: `list`
+
     :param groups: List of validation group
-    :type groups: `list` or a `string` of comma-separated groups
+    :type groups: `list`
+
+    :param categories: List of validation category
+    :type categories: `list`
+
+    :param products: List of validation product
+    :type products: `list`
+
     :return: A list of absolute validations playbooks path
     :rtype: `list`
 
@@ -194,19 +242,38 @@ def get_validations_playbook(path, validation_id=None, groups=None):
     >>> path = '/usr/share/validation-playbooks'
     >>> validation_id = ['512e','check-cpu']
     >>> groups = None
-    >>> get_validations_playbook(path, validation_id, groups)
+    >>> categories = None
+    >>> products = None
+    >>> get_validations_playbook(path=path,
+                                 validation_id=validation_id,
+                                 groups=groups,
+                                 categories=categories,
+                                 products=products)
     ['/usr/share/ansible/validation-playbooks/512e.yaml',
      '/usr/share/ansible/validation-playbooks/check-cpu.yaml',]
     """
+    if not isinstance(path, six.string_types):
+        raise TypeError("The 'path' argument must be a String")
+
     if not validation_id:
         validation_id = []
-    else:
-        validation_id = convert_data(validation_id)
+    elif not isinstance(validation_id, list):
+        raise TypeError("The 'validation_id' argument must be a List")
 
     if not groups:
         groups = []
-    else:
-        groups = convert_data(groups)
+    elif not isinstance(groups, list):
+        raise TypeError("The 'groups' argument must be a List")
+
+    if not categories:
+        categories = []
+    elif not isinstance(categories, list):
+        raise TypeError("The 'categories' argument must be a List")
+
+    if not products:
+        products = []
+    elif not isinstance(products, list):
+        raise TypeError("The 'products' argument must be a List")
 
     pl = []
     for f in os.listdir(path):
@@ -216,10 +283,17 @@ def get_validations_playbook(path, validation_id=None, groups=None):
                 if os.path.splitext(f)[0] in validation_id or \
                         os.path.basename(f) in validation_id:
                     pl.append(pl_path)
+
+            val = Validation(pl_path)
             if groups:
-                val = Validation(pl_path)
                 if set(groups).intersection(val.groups):
                     pl.append(pl_path)
+            if categories:
+                if set(categories).intersection(val.categories):
+                    pl.append(pl_path)
+            if products:
+                if set(products).intersection(val.products):
+                    pl.append(pl_path)
     return pl
 
 
@@ -283,11 +357,13 @@ def get_validations_details(validation):
     >>> get_validations_details(validation)
     {'description': 'Verify that the server has enough something.',
      'groups': ['group1', 'group2'],
+     'categories': ['category1', 'category2'],
+     'products': ['product1', 'product2'],
      'id': 'check-something',
      'name': 'Verify the server fits the something requirements'}
     """
     if not isinstance(validation, six.string_types):
-        raise TypeError("The input data should be a String")
+        raise TypeError("The 'validation' argument must be a String")
 
     results = parse_all_validations_on_disk(constants.ANSIBLE_VALIDATION_DIR)
     for r in results:
@@ -316,12 +392,14 @@ def get_validations_data(validation, path=constants.ANSIBLE_VALIDATION_DIR):
     >>> get_validations_data(validation)
     {'Description': 'Verify that the server has enough something',
      'Groups': ['group1', 'group2'],
+     'Categories': ['category1', 'category2'],
+     'products': ['product1', 'product2'],
      'ID': 'check-something',
      'Name': 'Verify the server fits the something requirements',
      'Parameters': {'param1': 24}}
     """
     if not isinstance(validation, six.string_types):
-        raise TypeError("The input data should be a String")
+        raise TypeError("The 'validation' argument must be a String")
 
     data = {}
     val_path = "{}/{}.yaml".format(path, validation)
@@ -339,17 +417,29 @@ def get_validations_data(validation, path=constants.ANSIBLE_VALIDATION_DIR):
     return data
 
 
-def get_validations_parameters(validations_data, validation_name=[],
-                               groups=[]):
+def get_validations_parameters(validations_data,
+                               validation_name=None,
+                               groups=None,
+                               categories=None,
+                               products=None):
     """Return parameters for a list of validations
 
 
     :param validations_data: A list of absolute validations playbooks path
     :type validations_data: `list`
+
     :param validation_name: A list of validation name
     :type validation_name: `list`
+
     :param groups: A list of validation groups
     :type groups: `list`
+
+    :param categories: A list of validation categories
+    :type categories: `list`
+
+    :param products: A list of validation products
+    :type products: `list`
+
     :return: a dictionary containing the current parameters for
              each `validation_name` or `groups`
     :rtype: `dict`
@@ -363,50 +453,38 @@ def get_validations_parameters(validations_data, validation_name=[],
     {'check-cpu': {'parameters': {'minimal_cpu_count': 8}},
      'check-ram': {'parameters': {'minimal_ram_gb': 24}}}
     """
+    if not isinstance(validations_data, list):
+        raise TypeError("The 'validations_data' argument must be a List")
+
+    if not validation_name:
+        validation_name = []
+    elif not isinstance(validation_name, list):
+        raise TypeError("The 'validation_name' argument must be a List")
+
+    if not groups:
+        groups = []
+    elif not isinstance(groups, list):
+        raise TypeError("The 'groups' argument must be a List")
+
+    if not categories:
+        categories = []
+    elif not isinstance(categories, list):
+        raise TypeError("The 'categories' argument must be a List")
+
+    if not products:
+        products = []
+    elif not isinstance(products, list):
+        raise TypeError("The 'products' argument must be a List")
+
     params = {}
     for val in validations_data:
         v = Validation(val)
-        if v.id in validation_name or set(groups).intersection(v.groups):
+        if v.id in validation_name or \
+           set(groups).intersection(v.groups) or \
+           set(categories).intersection(v.categories) or \
+           set(products).intersection(v.products):
             params[v.id] = {
                 'parameters': v.get_vars
             }
 
     return params
-
-
-def convert_data(data=''):
-    """Transform a string containing comma-separated validation or group name
-    into a list. If `data` is already a list, it will simply return `data`.
-
-    :param data: A string or a list
-    :type data: `string` or `list`
-    :return: A list of data
-    :rtype: `list`
-    :raises: a `TypeError` exception if `data` is not a list or a string
-
-    :Example:
-
-    >>> data = "check-cpu,check-ram,check-disk-space"
-    >>> convert_data(data)
-    ['check-cpu', 'check-ram', 'check-disk-space']
-    ...
-    >>> data = "check-cpu , check-ram , check-disk-space"
-    >>> convert_data(data)
-    ['check-cpu', 'check-ram', 'check-disk-space']
-    ...
-    >>> data = "check-cpu,"
-    >>> convert_data(data)
-    ['check-cpu']
-    ...
-    >>> data = ['check-cpu', 'check-ram', 'check-disk-space']
-    >>> convert_data(data)
-    ['check-cpu', 'check-ram', 'check-disk-space']
-    """
-    if isinstance(data, six.string_types):
-        return [
-            conv_data.strip() for conv_data in data.split(',') if conv_data
-        ]
-    elif not isinstance(data, list):
-        raise TypeError("The input data should be either a List or a String")
-    else:
-        return data
