@@ -14,11 +14,13 @@
 #
 import logging
 import os
+import sys
 import json
 import yaml
 
 from validations_libs.ansible import Ansible as v_ansible
 from validations_libs.group import Group
+from validations_libs.cli.common import Spinner
 from validations_libs.validation_logs import ValidationLogs, ValidationLog
 from validations_libs import constants
 from validations_libs import utils as v_utils
@@ -40,57 +42,84 @@ class ValidationActions(object):
 
     """
 
-    def __init__(self, validation_path=None, group=None):
+    def __init__(self, validation_path=None):
         self.log = logging.getLogger(__name__ + ".ValidationActions")
         self.validation_path = (validation_path if validation_path
                                 else constants.ANSIBLE_VALIDATION_DIR)
 
-    def list_validations(self, group=None):
-        """Get a list of the validations selected by group
-        membership. With their names and group membership information.
+    def list_validations(self,
+                         groups=None,
+                         categories=None,
+                         products=None):
+        """Get a list of the validations selected by group membership or by
+        category. With their names, group membership information, categories and
+        products.
+
         This is used to print table from python ``Tuple`` with ``PrettyTable``.
 
-        :param group: Group or multiple groups of validations.
-                      Additional groups have to be separated by comma.
-        :type group: `string`
+        :param groups: List of validation groups.
+        :type groups: `list`
+
+        :param categories: List of validation categories.
+        :type categories: `list`
+
+        :param products: List of validation products.
+        :type products: `list`
 
         :return: Column names and a list of the selected validations
         :rtype: `tuple`
 
         .. code:: text
 
-            ----------------+--------------------------+----------------------+
-            | ID            | Name                     | Groups               |
-            +---------------+--------------------------+----------------------+
-            | validation1   | Name of the validation1  | ['group1']           |
-            | validation2   | Name of the validation2  | ['group1', 'group2'] |
-            | validation3   | Name of the validation3  | ['group4]            |
-            +---------------+--------------------------+----------------------+
+            -------+-----------+----------------------+---------------+--------------+
+            | ID   | Name      | Groups               | Categories    | Products     |
+            +------+-----------+----------------------+---------------+--------------+
+            | val1 | val_name1 | ['group1']           | ['category1'] | ['product1'] |
+            | val2 | val_name2 | ['group1', 'group2'] | ['category2'] | ['product2'] |
+            | val3 | val_name3 | ['group4']           | ['category3'] | ['product3'] |
+            +------+-----------+----------------------+---------------+--------------+
 
         :Example:
 
         >>> path = "/foo/bar"
+        >>> groups = ['group1']
+        >>> categories = ['category1']
         >>> action = ValidationActions(validation_path=path)
-        >>> results = action.list_validations()
-        >>> print(results)
-        (('ID', 'Name', 'Groups'),
-         [('validation1', 'Name of the validation1', ['group1']),
-          ('validation2', 'Name of the validation2', ['group1', 'group2'])])
+        >>> results = action.list_validations(groups=groups,
+                                              categories=categories)
+        >>> print(results
+        (('ID', 'Name', 'Groups', 'Categories', 'Products'),
+         [('val1',
+           'val_name1',
+           ['group1'],
+           ['category1'],
+           ['product1']),
+          ('val2',
+           'val_name2',
+           ['group1', 'group2'],
+           ['category2'],
+           ['product2'])])
         """
         self.log = logging.getLogger(__name__ + ".list_validations")
 
         validations = v_utils.parse_all_validations_on_disk(
-            self.validation_path, group)
+            path=self.validation_path,
+            groups=groups,
+            categories=categories,
+            products=products
+        )
 
         self.log.debug(
             "Parsed {} validations.".format(len(validations))
         )
 
         return_values = [
-            (val.get('id'), val.get('name'), val.get('groups'))
+            (val.get('id'), val.get('name'),
+             val.get('groups'), val.get('categories'),
+             val.get('products'))
             for val in validations]
 
-        column_names = ('ID', 'Name', 'Groups')
+        column_names = ('ID', 'Name', 'Groups', 'Categories', 'Products')
 
         return (column_names, return_values)
 
@@ -115,6 +144,7 @@ class ValidationActions(object):
         >>> print(results)
         {
          'Description': 'Description of the foo validation',
+         'Categories': ['category1', 'category2'],
          'Groups': ['group1', 'group2'],
          'ID': 'foo',
          'Last execution date': None,
@@ -229,17 +259,17 @@ class ValidationActions(object):
         return [path[1] for path in logs[-history_limit:]]
 
     def run_validations(self, validation_name=None, inventory='localhost',
-                        group=None, extra_vars=None, validations_dir=None,
+                        group=None, category=None, product=None,
+                        extra_vars=None, validations_dir=None,
                         extra_env_vars=None, ansible_cfg=None, quiet=True,
                         workdir=None, limit_hosts=None, run_async=False,
                         base_dir=constants.DEFAULT_VALIDATIONS_BASEDIR,
                         log_path=constants.VALIDATIONS_LOG_BASEDIR,
-                        python_interpreter=None,
-                        skip_list=None,
+                        python_interpreter=None, skip_list=None,
                         callback_whitelist=None,
-                        output_callback='validation_stdout',
-                        ssh_user=None):
-        """Run one or multiple validations by name(s) or by group(s)
+                        output_callback='validation_stdout', ssh_user=None):
+        """Run one or multiple validations by name(s), by group(s) or by
+        product(s)
 
         :param validation_name: A list of validation names
         :type validation_name: ``list``
@@ -248,6 +278,10 @@ class ValidationActions(object):
         :type inventory: ``string``
         :param group: A list of group names
         :type group: ``list``
+        :param category: A list of category names
+        :type category: ``list``
+        :param product: A list of product names
+        :type product: ``list``
         :param extra_vars: Set additional variables as a Dict or the absolute
                            path of a JSON or YAML file type.
         :type extra_vars: Either a Dict or the absolute path of JSON or YAML
@@ -331,21 +365,22 @@ class ValidationActions(object):
         playbooks = []
         validations_dir = (validations_dir if validations_dir
                            else self.validation_path)
-        if group:
-            self.log.debug('Getting the validations list by group')
-            try:
-                validations = v_utils.parse_all_validations_on_disk(
-                    validations_dir, group)
-                for val in validations:
-                    playbooks.append(val.get('id') + '.yaml')
-            except Exception as e:
-                raise(e)
+        if group or category or product:
+            self.log.debug(
+                "Getting the validations list by:\n"
+                "  - groups: {}\n"
+                "  - categories: {}\n"
+                "  - products: {}".format(group, category, product)
+            )
+            validations = v_utils.parse_all_validations_on_disk(
+                path=validations_dir, groups=group,
+                categories=category, products=product
+            )
+            for val in validations:
+                playbooks.append(val.get('id') + '.yaml')
         elif validation_name:
-            validation_name = v_utils.convert_data(validation_name)
-
             playbooks = v_utils.get_validations_playbook(validations_dir,
-                                                         validation_name,
-                                                         group)
+                                                         validation_name)
 
             if not playbooks or len(validation_name) != len(playbooks):
                 p = []
@@ -374,26 +409,49 @@ class ValidationActions(object):
                 validation_uuid, artifacts_dir = v_utils.create_artifacts_dir(
                     log_path=log_path, prefix=os.path.basename(playbook))
                 run_ansible = v_ansible(validation_uuid)
-                _playbook, _rc, _status = run_ansible.run(
-                    workdir=artifacts_dir,
-                    playbook=playbook,
-                    base_dir=base_dir,
-                    playbook_dir=validations_dir,
-                    parallel_run=True,
-                    inventory=inventory,
-                    output_callback=output_callback,
-                    callback_whitelist=callback_whitelist,
-                    quiet=quiet,
-                    extra_vars=extra_vars,
-                    limit_hosts=_hosts,
-                    extra_env_variables=extra_env_vars,
-                    ansible_cfg=ansible_cfg,
-                    gathering_policy='explicit',
-                    ansible_artifact_path=artifacts_dir,
-                    log_path=log_path,
-                    run_async=run_async,
-                    python_interpreter=python_interpreter,
-                    ssh_user=ssh_user)
+                if sys.__stdin__.isatty():
+                    with Spinner():
+                        _playbook, _rc, _status = run_ansible.run(
+                            workdir=artifacts_dir,
+                            playbook=playbook,
+                            base_dir=base_dir,
+                            playbook_dir=validations_dir,
+                            parallel_run=True,
+                            inventory=inventory,
+                            output_callback=output_callback,
+                            callback_whitelist=callback_whitelist,
+                            quiet=quiet,
+                            extra_vars=extra_vars,
+                            limit_hosts=_hosts,
+                            extra_env_variables=extra_env_vars,
+                            ansible_cfg=ansible_cfg,
+                            gathering_policy='explicit',
+                            ansible_artifact_path=artifacts_dir,
+                            log_path=log_path,
+                            run_async=run_async,
+                            python_interpreter=python_interpreter,
+                            ssh_user=ssh_user)
+                else:
+                    _playbook, _rc, _status = run_ansible.run(
+                        workdir=artifacts_dir,
+                        playbook=playbook,
+                        base_dir=base_dir,
+                        playbook_dir=validations_dir,
+                        parallel_run=True,
+                        inventory=inventory,
+                        output_callback=output_callback,
+                        callback_whitelist=callback_whitelist,
+                        quiet=quiet,
+                        extra_vars=extra_vars,
+                        limit_hosts=_hosts,
+                        extra_env_variables=extra_env_vars,
+                        ansible_cfg=ansible_cfg,
+                        gathering_policy='explicit',
+                        ansible_artifact_path=artifacts_dir,
+                        log_path=log_path,
+                        run_async=run_async,
+                        python_interpreter=python_interpreter,
+                        ssh_user=ssh_user)
                 results.append({'playbook': _playbook,
                                 'rc_code': _rc,
                                 'status': _status,
@@ -455,17 +513,28 @@ class ValidationActions(object):
         column_name = ("Groups", "Description", "Number of Validations")
         return (column_name, group_info)
 
-    def show_validations_parameters(self, validation=None, group=None,
-                                    output_format='json', download_file=None):
+    def show_validations_parameters(self,
+                                    validations=None,
+                                    groups=None,
+                                    categories=None,
+                                    products=None,
+                                    output_format='json',
+                                    download_file=None):
         """
         Return Validations Parameters for one or several validations by their
-        names or their groups.
+        names, their groups, by their categories or by their products.
 
-        :param validation: List of validation name(s)
-        :type validation: `list`
+        :param validations: List of validation name(s)
+        :type validations: `list`
 
-        :param group: List of validation group(s)
-        :type group: `list`
+        :param groups: List of validation group(s)
+        :type groups: `list`
+
+        :param categories: List of validation category(ies)
+        :type categories: `list`
+
+        :param products: List of validation product(s)
+        :type products: `list`
 
         :param output_format: Output format (Supported format are JSON or YAML)
         :type output_format: `string`
@@ -479,10 +548,13 @@ class ValidationActions(object):
                  parameters will be created in the file system.
         :exemple:
 
-        >>> validation = ['check-cpu', 'check-ram']
-        >>> group = None
+        >>> validations = ['check-cpu', 'check-ram']
+        >>> groups = None
+        >>> categories = None
+        >>> products = None
         >>> output_format = 'json'
-        >>> show_validations_parameters(validation, group, output_format)
+        >>> show_validations_parameters(validations, groups,
+                                        categories, products, output_format)
         {
             "check-cpu": {
                 "parameters": {
@@ -496,21 +568,47 @@ class ValidationActions(object):
             }
         }
         """
-        if not validation:
-            validation = []
+        if not validations:
+            validations = []
+        elif not isinstance(validations, list):
+            raise TypeError("The 'validations' argument must be a List")
 
-        if not group:
-            group = []
+        if not groups:
+            groups = []
+        elif not isinstance(groups, list):
+            raise TypeError("The 'groups' argument must be a List")
+
+        if not categories:
+            categories = []
+        elif not isinstance(categories, list):
+            raise TypeError("The 'categories' argument must be a List")
+
+        if not products:
+            products = []
+        elif not isinstance(products, list):
+            raise TypeError("The 'products' argument must be a List")
 
         supported_format = ['json', 'yaml']
 
         if output_format not in supported_format:
             raise RuntimeError("{} output format not supported".format(output_format))
 
-        validations = v_utils.get_validations_playbook(
-            self.validation_path, validation, group)
-        params = v_utils.get_validations_parameters(validations, validation,
-                                                    group)
+        validation_playbooks = v_utils.get_validations_playbook(
+            path=self.validation_path,
+            validation_id=validations,
+            groups=groups,
+            categories=categories,
+            products=products
+        )
+
+        params = v_utils.get_validations_parameters(
+            validations_data=validation_playbooks,
+            validation_name=validations,
+            groups=groups,
+            categories=categories,
+            products=products
+        )
+
         if download_file:
             params_only = {}
             try:
